==> haskell-cprng-aes-0.6.1-21-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cprng-aes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cprng-aes
version: 0.6.1
id: cprng-aes-0.6.1-FnxPepCKI9pHZaZ3AStxla
key: cprng-aes-0.6.1-FnxPepCKI9pHZaZ3AStxla
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-cprng-aes
synopsis: Crypto Pseudo Random Number Generator using AES in counter mode.
description:
    Simple crypto pseudo-random-number-generator with really good randomness property.
    .
    Using ent, a randomness property maker on one 1Mb sample:
    Entropy = 7.999837 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 237.02
    Arithmetic mean value of data bytes is 127.3422 (127.5 = random)
    Monte Carlo value for Pi is 3.143589568 (error 0.06 percent)
    .
    Compared to urandom with the same sampling:
    Entropy = 7.999831 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 246.63
    Arithmetic mean value of data bytes is 127.6347 (127.5 = random).
    Monte Carlo value for Pi is 3.132465868 (error 0.29 percent).
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Crypto.Random.AESCtr
hidden-modules: Crypto.Random.AESCtr.Internal
abi: dc2a7b16b922cad351656b65087bbd4f
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/cprng-aes-0.6.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/cprng-aes-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-cprng-aes
hs-libraries: HScprng-aes-0.6.1-FnxPepCKI9pHZaZ3AStxla
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    byteable-0.1.1-3VfNJqauCum9lD10cS8nmH
    crypto-random-0.0.9-B75YygnKCDoK2KXR01Og31
    cipher-aes-0.2.11-DVdARdSY56t9L6eIwC7pQC
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             byteable-0.1.1-3VfNJqauCum9lD10cS8nmH=d344f7951d5abb0484f8cf34bb5d3e34
             crypto-random-0.0.9-B75YygnKCDoK2KXR01Og31=23d9fdcab31b7d29f53780c173c67ec2
             cipher-aes-0.2.11-DVdARdSY56t9L6eIwC7pQC=fabaef2cec7043f7e110a772c1ffa93a
haddock-interfaces: /usr/share/doc/haskell-cprng-aes/html/cprng-aes.haddock
haddock-html: /usr/share/doc/haskell-cprng-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cprng-aes-0.6.1-22-i686.pkg.tar.xz: usr/share/haskell/register/haskell-cprng-aes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cprng-aes
version: 0.6.1
id: cprng-aes-0.6.1-ALdmCX25xcJHuR2HRZDwXZ
key: cprng-aes-0.6.1-ALdmCX25xcJHuR2HRZDwXZ
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-cprng-aes
synopsis: Crypto Pseudo Random Number Generator using AES in counter mode.
description:
    Simple crypto pseudo-random-number-generator with really good randomness property.
    .
    Using ent, a randomness property maker on one 1Mb sample:
    Entropy = 7.999837 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 237.02
    Arithmetic mean value of data bytes is 127.3422 (127.5 = random)
    Monte Carlo value for Pi is 3.143589568 (error 0.06 percent)
    .
    Compared to urandom with the same sampling:
    Entropy = 7.999831 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 246.63
    Arithmetic mean value of data bytes is 127.6347 (127.5 = random).
    Monte Carlo value for Pi is 3.132465868 (error 0.29 percent).
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Crypto.Random.AESCtr
hidden-modules: Crypto.Random.AESCtr.Internal
abi: f14d598862da4663d557cf7cc6fc0797
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/cprng-aes-0.6.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/cprng-aes-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-cprng-aes
hs-libraries: HScprng-aes-0.6.1-ALdmCX25xcJHuR2HRZDwXZ
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    byteable-0.1.1-3VfNJqauCum9lD10cS8nmH
    crypto-random-0.0.9-3hO7lgyx579EdJGw5NW2lQ
    cipher-aes-0.2.11-JMmiNCTVX2UFTUW7O3JqxF
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             byteable-0.1.1-3VfNJqauCum9lD10cS8nmH=d344f7951d5abb0484f8cf34bb5d3e34
             crypto-random-0.0.9-3hO7lgyx579EdJGw5NW2lQ=0005dd32aab7c97f2d823516b0f83a6c
             cipher-aes-0.2.11-JMmiNCTVX2UFTUW7O3JqxF=7bc2c56670c180e81a953577e528c527
haddock-interfaces: /usr/share/doc/haskell-cprng-aes/html/cprng-aes.haddock
haddock-html: /usr/share/doc/haskell-cprng-aes/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
